@@ -3,23 +3,24 @@ mod test_controller;
 mod test_struct;
 
 use netxclient::*;
-use std::time::Instant;
-
-use crate::test_struct::{LogOn, LogOnResult};
 use log::LevelFilter;
 use server::*;
 use std::error::Error;
 use test_controller::TestController;
+use std::time::Instant;
+use crate::test_struct::{LogOn, LogOnResult};
 
 #[global_allocator]
 static GLOBAL: mimalloc::MiMalloc = mimalloc::MiMalloc;
 
 #[tokio::main]
 async fn main() -> Result<(), Box<dyn Error>> {
+
     env_logger::Builder::default()
         .filter_level(LevelFilter::Debug)
         .init();
 
+
     let client = {
         cfg_if::cfg_if! {
         if #[cfg(feature = "tls")]{
@@ -55,14 +56,15 @@ async fn main() -> Result<(), Box<dyn Error>> {
     server.print(5).await?;
 
     // call!(@checkrun client=>700;"joy");
-    server.run_test("joy".into()).await?;
+    server.run_test(Some("jon")).await?;
 
     //let x:i32=call!(client=>1003;1);
     let x = server.to_client_add_one(1).await?;
     assert_eq!(x, 2);
 
+
     // call!(@checkrun client=>600;6,"my name is");
-    server.print2(6, "my name is".into()).await?;
+    server.print2(6, "my name is").await?;
 
     let start = Instant::now();
 
